<!--startmeta
custom_edit_url: "https://github.com/netdata/netdata/edit/master/src/go/plugin/go.d/modules/riakkv/README.md"
meta_yaml: "https://github.com/netdata/netdata/edit/master/src/go/plugin/go.d/modules/riakkv/metadata.yaml"
sidebar_label: "Riak KV"
learn_status: "Published"
learn_rel_path: "Collecting Metrics/Databases"
most_popular: False
message: "DO NOT EDIT THIS FILE DIRECTLY, IT IS GENERATED BY THE COLLECTOR'S metadata.yaml FILE"
endmeta-->

# Riak KV


<img src="https://netdata.cloud/img/riak.svg" width="150"/>


Plugin: go.d.plugin
Module: riakkv

<img src="https://img.shields.io/badge/maintained%20by-Netdata-%2300ab44" />

## Overview

This collector monitors RiakKV metrics about throughput, latency, resources and more.


It sends HTTP requests to the Riak [/stats](https://docs.riak.com/riak/kv/2.2.3/developing/api/http/status.1.html) endpoint.


This collector is supported on all platforms.

This collector supports collecting metrics from multiple instances of this integration, including remote instances.


### Default Behavior

#### Auto-Detection

By default, it detects Riak instances running on localhost that are listening on port 8098.
On startup, it tries to collect metrics from:

- http://127.0.0.1:8098/stats


#### Limits

The default configuration for this integration does not impose any limits on data collection.

#### Performance Impact

The default configuration for this integration is not expected to impose a significant performance impact on the system.


## Metrics

Metrics grouped by *scope*.

The scope defines the instance that the metric belongs to. An instance is uniquely identified by a set of labels.



### Per Riak KV instance

These metrics refer to the entire monitored application.

This scope has no labels.

Metrics:

| Metric | Dimensions | Unit |
|:------|:----------|:----|
| riak.kv.throughput | gets, puts | operations/s |
| riak.dt.vnode_updates | counters, sets, maps | operations/s |
| riak.search | queries | queries/s |
| riak.search.documents | indexed | documents/s |
| riak.consistent.operations | gets, puts | operations/s |
| riak.kv.latency.get | mean, median, 95, 99, 100 | ms |
| riak.kv.latency.put | mean, median, 95, 99, 100 | ms |
| riak.dt.latency.counter_merge | mean, median, 95, 99, 100 | ms |
| riak.dt.latency.set_merge | mean, median, 95, 99, 100 | ms |
| riak.dt.latency.map_merge | mean, median, 95, 99, 100 | ms |
| riak.search.latency.query | median, min, 95, 99, 999, max | ms |
| riak.search.latency.index | median, min, 95, 99, 999, max | ms |
| riak.consistent.latency.get | mean, median, 95, 99, 100 | ms |
| riak.consistent.latency.put | mean, median, 95, 99, 100 | ms |
| riak.vm | processes | total |
| riak.vm.memory.processes | allocated, used | MB |
| riak.kv.siblings_encountered.get | mean, median, 95, 99, 100 | siblings |
| riak.kv.objsize.get | mean, median, 95, 99, 100 | KB |
| riak.search.vnodeq_size | mean, median, 95, 99, 100 | messages |
| riak.search.index | index_fail, bad_entry, extract_fail | errors |
| riak.core.protobuf_connections | active | connections |
| riak.core.repairs | read | repairs |
| riak.core.fsm_active | get, put, secondary index, list keys | fsms |
| riak.core.fsm_rejected | get, put | fsms |



## Alerts

There are no alerts configured by default for this integration.


## Setup

### Prerequisites

#### Enable /stats endpoint

See the RiakKV [configuration reference](https://docs.riak.com/riak/kv/2.2.3/developing/api/http/status.1.html).



### Configuration

#### File

The configuration file name for this integration is `go.d/riakkv.conf`.


You can edit the configuration file using the [`edit-config`](https://github.com/netdata/netdata/blob/master/docs/netdata-agent/configuration/README.md#edit-a-configuration-file-using-edit-config) script from the
Netdata [config directory](https://github.com/netdata/netdata/blob/master/docs/netdata-agent/configuration/README.md#the-netdata-config-directory).

```bash
cd /etc/netdata 2>/dev/null || cd /opt/netdata/etc/netdata
sudo ./edit-config go.d/riakkv.conf
```
#### Options

The following options can be defined globally: update_every, autodetection_retry.


<details open><summary>Config options</summary>

| Name | Description | Default | Required |
|:----|:-----------|:-------|:--------:|
| update_every | Data collection frequency. | 1 | no |
| autodetection_retry | Recheck interval in seconds. Zero means no recheck will be scheduled. | 0 | no |
| url | Server URL. | http://127.0.0.1:8098/stats | yes |
| timeout | HTTP request timeout. | 1 | no |
| username | Username for basic HTTP authentication. |  | no |
| password | Password for basic HTTP authentication. |  | no |
| proxy_url | Proxy URL. |  | no |
| proxy_username | Username for proxy basic HTTP authentication. |  | no |
| proxy_password | Password for proxy basic HTTP authentication. |  | no |
| method | HTTP request method. | GET | no |
| body | HTTP request body. |  | no |
| headers | HTTP request headers. |  | no |
| not_follow_redirects | Redirect handling policy. Controls whether the client follows redirects. | no | no |
| tls_skip_verify | Server certificate chain and hostname validation policy. Controls whether the client performs this check. | no | no |
| tls_ca | Certification authority that the client uses when verifying the server's certificates. |  | no |
| tls_cert | Client TLS certificate. |  | no |
| tls_key | Client TLS key. |  | no |

</details>

#### Examples

##### Basic

A basic example configuration.

```yaml
jobs:
  - name: local
    url: http://127.0.0.1:8098/stats

```
##### HTTP authentication

Basic HTTP authentication.

<details open><summary>Config</summary>

```yaml
jobs:
  - name: local
    url: http://127.0.0.1:8098/stats
    username: username
    password: password

```
</details>

##### HTTPS with self-signed certificate

With enabled HTTPS and self-signed certificate.

<details open><summary>Config</summary>

```yaml
jobs:
  - name: local
    url: http://127.0.0.1:8098/stats
    tls_skip_verify: yes

```
</details>

##### Multi-instance

> **Note**: When you define multiple jobs, their names must be unique.

Collecting metrics from local and remote instances.


<details open><summary>Config</summary>

```yaml
jobs:
  - name: local
    url: http://127.0.0.1:8098/stats

  - name: remote
    url: http://192.0.2.1:8098/stats

```
</details>



## Troubleshooting

### Debug Mode

**Important**: Debug mode is not supported for data collection jobs created via the UI using the Dyncfg feature.

To troubleshoot issues with the `riakkv` collector, run the `go.d.plugin` with the debug option enabled. The output
should give you clues as to why the collector isn't working.

- Navigate to the `plugins.d` directory, usually at `/usr/libexec/netdata/plugins.d/`. If that's not the case on
  your system, open `netdata.conf` and look for the `plugins` setting under `[directories]`.

  ```bash
  cd /usr/libexec/netdata/plugins.d/
  ```

- Switch to the `netdata` user.

  ```bash
  sudo -u netdata -s
  ```

- Run the `go.d.plugin` to debug the collector:

  ```bash
  ./go.d.plugin -d -m riakkv
  ```

### Getting Logs

If you're encountering problems with the `riakkv` collector, follow these steps to retrieve logs and identify potential issues:

- **Run the command** specific to your system (systemd, non-systemd, or Docker container).
- **Examine the output** for any warnings or error messages that might indicate issues.  These messages should provide clues about the root cause of the problem.

#### System with systemd

Use the following command to view logs generated since the last Netdata service restart:

```bash
journalctl _SYSTEMD_INVOCATION_ID="$(systemctl show --value --property=InvocationID netdata)" --namespace=netdata --grep riakkv
```

#### System without systemd

Locate the collector log file, typically at `/var/log/netdata/collector.log`, and use `grep` to filter for collector's name:

```bash
grep riakkv /var/log/netdata/collector.log
```

**Note**: This method shows logs from all restarts. Focus on the **latest entries** for troubleshooting current issues.

#### Docker Container

If your Netdata runs in a Docker container named "netdata" (replace if different), use this command:

```bash
docker logs netdata 2>&1 | grep riakkv
```


